@@ -197,7 +197,7 @@ typedef struct _CoglTexturePixmapEGL
 #undef COGL_WINSYS_FEATURE_BEGIN
 #define COGL_WINSYS_FEATURE_BEGIN(name, namespaces, extension_names,    \
                                   egl_private_flags)                    \
-  { 255, 255, namespaces, extension_names,                              \
+  { 255, 255, 0, namespaces, extension_names,                           \
       0, egl_private_flags,                                             \
       0,                                                                \
       cogl_egl_feature_ ## name ## _funcs },
@@ -354,11 +354,12 @@ check_egl_extensions (CoglRenderer *renderer)
   for (i = 0; i < G_N_ELEMENTS (winsys_feature_data); i++)
     if (_cogl_feature_check (winsys,
                              "EGL", winsys_feature_data + i, 0, 0,
+                             COGL_DRIVER_GL, /* the driver isn't used */
                              egl_extensions,
                              egl_renderer))
       {
         egl_renderer->private_features |=
-          winsys_feature_data[0].feature_flags_private;
+          winsys_feature_data[i].feature_flags_private;
       }
 }
 
@@ -502,19 +503,20 @@ error:
   return FALSE;
 }
 
-static void
-update_winsys_features (CoglContext *context)
+static gboolean
+update_winsys_features (CoglContext *context, GError **error)
 {
   CoglDisplayEGL *egl_display = context->display->winsys;
   CoglRendererEGL *egl_renderer = context->display->renderer->winsys;
 
-  g_return_if_fail (egl_display->egl_context);
+  g_return_val_if_fail (egl_display->egl_context, FALSE);
 
   memset (context->winsys_features, 0, sizeof (context->winsys_features));
 
   check_egl_extensions (context->display->renderer);
 
-  _cogl_gl_update_features (context);
+  if (!_cogl_context_update_features (context, error))
+    return FALSE;
 
 #if defined (COGL_HAS_EGL_PLATFORM_POWERVR_X11_SUPPORT) || \
     defined (COGL_HAS_EGL_PLATFORM_WAYLAND_SUPPORT)
@@ -531,6 +533,8 @@ update_winsys_features (CoglContext *context)
       COGL_FLAGS_SET (context->winsys_features,
                       COGL_WINSYS_FEATURE_SWAP_REGION_THROTTLE, TRUE);
     }
+
+  return TRUE;
 }
 
 #ifdef COGL_HAS_EGL_PLATFORM_POWERVR_X11_SUPPORT
@@ -619,23 +623,17 @@ try_create_context (CoglDisplay *display,
 
     EGL_BUFFER_SIZE,     EGL_DONT_CARE,
 
-#if defined (HAVE_COGL_GL)
-    EGL_RENDERABLE_TYPE, EGL_OPENGL_BIT,
-#elif defined (HAVE_COGL_GLES2)
-    EGL_RENDERABLE_TYPE, EGL_OPENGL_ES2_BIT,
-#else
-    EGL_RENDERABLE_TYPE, EGL_OPENGL_ES_BIT,
-#endif
+    EGL_RENDERABLE_TYPE, (display->renderer->driver == COGL_DRIVER_GL ?
+                          EGL_OPENGL_BIT :
+                          display->renderer->driver == COGL_DRIVER_GLES1 ?
+                          EGL_OPENGL_ES_BIT :
+                          EGL_OPENGL_ES2_BIT),
 
     EGL_SURFACE_TYPE,    EGL_WINDOW_BIT,
 
     EGL_NONE
   };
-#if defined (HAVE_COGL_GLES2)
-  EGLint attribs[] = { EGL_CONTEXT_CLIENT_VERSION, 2, EGL_NONE };
-#else
-  EGLint *attribs = NULL;
-#endif
+  EGLint attribs[3];
 
 #ifdef COGL_HAS_EGL_PLATFORM_POWERVR_X11_SUPPORT
   XVisualInfo *xvisinfo;
@@ -646,11 +644,19 @@ try_create_context (CoglDisplay *display,
 #endif
   const char *error_message;
 
+  if (display->renderer->driver == COGL_DRIVER_GLES2)
+    {
+      attribs[0] = EGL_CONTEXT_CLIENT_VERSION;
+      attribs[1] = 2;
+      attribs[2] = EGL_NONE;
+    }
+  else
+    attribs[0] = EGL_NONE;
+
   edpy = egl_renderer->edpy;
 
-#ifdef HAVE_COGL_GL
-  eglBindAPI (EGL_OPENGL_API);
-#endif
+  if (display->renderer->driver == COGL_DRIVER_GL)
+    eglBindAPI (EGL_OPENGL_API);
 
   /* Some GLES hardware can't support a stencil buffer: */
   if (retry_cookie == 1)
@@ -1111,9 +1117,7 @@ _cogl_winsys_context_init (CoglContext *context, GError **error)
                                  event_filter_cb,
                                  context);
 #endif
-  update_winsys_features (context);
-
-  return TRUE;
+  return update_winsys_features (context, error);
 }
 
 static void
@@ -1553,13 +1557,16 @@ _cogl_winsys_texture_pixmap_x11_create (CoglTexturePixmapX11 *tex_pixmap)
   CoglTexturePixmapEGL *egl_tex_pixmap;
   EGLint attribs[] = {EGL_IMAGE_PRESERVED_KHR, EGL_TRUE, EGL_NONE};
   CoglPixelFormat texture_format;
+  CoglRendererEGL *egl_renderer;
 
   /* FIXME: It should be possible to get to a CoglContext from any
    * CoglTexture pointer. */
   _COGL_GET_CONTEXT (ctx, FALSE);
 
-  if (!(ctx->private_feature_flags &
-        COGL_PRIVATE_FEATURE_EGL_IMAGE_FROM_X11_PIXMAP) ||
+  egl_renderer = ctx->display->renderer->winsys;
+
+  if (!(egl_renderer->private_features &
+        COGL_EGL_WINSYS_FEATURE_EGL_IMAGE_FROM_X11_PIXMAP) ||
       !(ctx->private_feature_flags &
         COGL_PRIVATE_FEATURE_TEXTURE_2D_FROM_EGL_IMAGE))
     {
@@ -1575,7 +1582,10 @@ _cogl_winsys_texture_pixmap_x11_create (CoglTexturePixmapX11 *tex_pixmap)
                             (EGLClientBuffer)tex_pixmap->pixmap,
                             attribs);
   if (egl_tex_pixmap->image == EGL_NO_IMAGE_KHR)
-    return FALSE;
+    {
+      g_free (egl_tex_pixmap);
+      return FALSE;
+    }
 
   texture_format = (tex_pixmap->depth >= 32 ?
                     COGL_PIXEL_FORMAT_RGBA_8888_PRE :
